nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Sts2

Struct Sts2 

#[repr(transparent)]
pub struct Sts2(pub u32);
Status 2

Tuple Fields

0: u32

Implementations

Source

impl Sts2

pub const fn aslvlock(&self) -> Aslvlock

Flash A Sample Target Delay Line Locked

pub const fn set_aslvlock(&mut self, val: Aslvlock)

Flash A Sample Target Delay Line Locked

pub const fn areflock(&self) -> Areflock

Flash A Sample Clock Reference Delay Line Locked

pub const fn set_areflock(&mut self, val: Areflock)

Flash A Sample Clock Reference Delay Line Locked

pub const fn aslvsel(&self) -> u8

Flash A Sample Clock Target Delay Line Delay Cell Number

pub const fn set_aslvsel(&mut self, val: u8)

Flash A Sample Clock Target Delay Line Delay Cell Number

pub const fn arefsel(&self) -> u8

Flash A Sample Clock Reference Delay Line Delay Cell Number

pub const fn set_arefsel(&mut self, val: u8)

Flash A Sample Clock Reference Delay Line Delay Cell Number

pub const fn bslvlock(&self) -> Bslvlock

Flash B Sample Target Reference Delay Line Locked

pub const fn set_bslvlock(&mut self, val: Bslvlock)

Flash B Sample Target Reference Delay Line Locked

pub const fn breflock(&self) -> Breflock

Flash B Sample Clock Reference Delay Line Locked

pub const fn set_breflock(&mut self, val: Breflock)

Flash B Sample Clock Reference Delay Line Locked

pub const fn bslvsel(&self) -> u8

Flash B Sample Clock Target Delay Line Delay Cell Number

pub const fn set_bslvsel(&mut self, val: u8)

Flash B Sample Clock Target Delay Line Delay Cell Number

pub const fn brefsel(&self) -> u8

Flash B Sample Clock Reference Delay Line Delay Cell Number

pub const fn set_brefsel(&mut self, val: u8)

Flash B Sample Clock Reference Delay Line Delay Cell Number