#[repr(transparent)]pub struct Sts2(pub u32);Expand description
Status 2
Tuple Fields
0: u32Implementations
Sourceimpl Sts2
impl Sts2
Sourcepub const fn set_aslvlock(&mut self, val: Aslvlock)
pub const fn set_aslvlock(&mut self, val: Aslvlock)
Flash A Sample Target Delay Line Locked
Sourcepub const fn set_areflock(&mut self, val: Areflock)
pub const fn set_areflock(&mut self, val: Areflock)
Flash A Sample Clock Reference Delay Line Locked
Sourcepub const fn set_aslvsel(&mut self, val: u8)
pub const fn set_aslvsel(&mut self, val: u8)
Flash A Sample Clock Target Delay Line Delay Cell Number
Sourcepub const fn set_arefsel(&mut self, val: u8)
pub const fn set_arefsel(&mut self, val: u8)
Flash A Sample Clock Reference Delay Line Delay Cell Number
Sourcepub const fn set_bslvlock(&mut self, val: Bslvlock)
pub const fn set_bslvlock(&mut self, val: Bslvlock)
Flash B Sample Target Reference Delay Line Locked
Sourcepub const fn set_breflock(&mut self, val: Breflock)
pub const fn set_breflock(&mut self, val: Breflock)
Flash B Sample Clock Reference Delay Line Locked
Sourcepub const fn set_bslvsel(&mut self, val: u8)
pub const fn set_bslvsel(&mut self, val: u8)
Flash B Sample Clock Target Delay Line Delay Cell Number
Sourcepub const fn set_brefsel(&mut self, val: u8)
pub const fn set_brefsel(&mut self, val: u8)
Flash B Sample Clock Reference Delay Line Delay Cell Number